@@ -126,9 +126,9 @@ typedef struct rz_io_plugin_t {
 	char *(*system)(RzIO *io, RzIODesc *fd, const char *);
 	RzIODesc *(*open)(RzIO *io, const char *, int perm, int mode);
 	RzList /*<RzIODesc *>*/ *(*open_many)(RzIO *io, const char *, int perm, int mode);
-	int (*read)(RzIO *io, RzIODesc *fd, ut8 *buf, int count);
+	int (*read)(RzIO *io, RzIODesc *fd, ut8 *buf, size_t len);
 	ut64 (*lseek)(RzIO *io, RzIODesc *fd, ut64 offset, int whence);
-	int (*write)(RzIO *io, RzIODesc *fd, const ut8 *buf, int count);
+	int (*write)(RzIO *io, RzIODesc *fd, const ut8 *buf, size_t len);
 	int (*close)(RzIODesc *desc);
 	bool (*is_blockdevice)(RzIODesc *desc);
 	bool (*is_chardevice)(RzIODesc *desc);
@@ -175,7 +175,7 @@ typedef struct rz_io_desc_cache_t {
 typedef struct rz_event_io_write_t {
 	ut64 addr;
 	const ut8 *buf;
-	int len;
+	size_t len;
 } RzEventIOWrite;
 
 typedef struct rz_event_io_desc_close_t {
@@ -195,8 +195,8 @@ typedef ut64 (*RzIODescSize)(RzIODesc *desc);
 typedef RzIODesc *(*RzIOOpen)(RzIO *io, const char *uri, int flags, int mode);
 typedef RzIODesc *(*RzIOOpenAt)(RzIO *io, const char *uri, int flags, int mode, ut64 at, RZ_NULLABLE RZ_OUT RzIOMap **map);
 typedef bool (*RzIOClose)(RzIO *io, int fd);
-typedef bool (*RzIOReadAt)(RzIO *io, ut64 addr, ut8 *buf, int len);
-typedef bool (*RzIOWriteAt)(RzIO *io, ut64 addr, const ut8 *buf, int len);
+typedef bool (*RzIOReadAt)(RzIO *io, ut64 addr, ut8 *buf, size_t len);
+typedef bool (*RzIOWriteAt)(RzIO *io, ut64 addr, const ut8 *buf, size_t len);
 typedef char *(*RzIOSystem)(RzIO *io, const char *cmd);
 typedef int (*RzIOFdOpen)(RzIO *io, const char *uri, int flags, int mode);
 typedef bool (*RzIOFdClose)(RzIO *io, int fd);
@@ -205,10 +205,10 @@ typedef ut64 (*RzIOFdSize)(RzIO *io, int fd);
 typedef bool (*RzIOFdResize)(RzIO *io, int fd, ut64 newsize);
 typedef ut64 (*RzIOP2V)(RzIO *io, ut64 pa);
 typedef ut64 (*RzIOV2P)(RzIO *io, ut64 va);
-typedef int (*RzIOFdRead)(RzIO *io, int fd, ut8 *buf, int len);
-typedef int (*RzIOFdWrite)(RzIO *io, int fd, const ut8 *buf, int len);
-typedef int (*RzIOFdReadAt)(RzIO *io, int fd, ut64 addr, ut8 *buf, int len);
-typedef int (*RzIOFdWriteAt)(RzIO *io, int fd, ut64 addr, const ut8 *buf, int len);
+typedef int (*RzIOFdRead)(RzIO *io, int fd, ut8 *buf, size_t len);
+typedef int (*RzIOFdWrite)(RzIO *io, int fd, const ut8 *buf, size_t len);
+typedef int (*RzIOFdReadAt)(RzIO *io, int fd, ut64 addr, ut8 *buf, size_t len);
+typedef int (*RzIOFdWriteAt)(RzIO *io, int fd, ut64 addr, const ut8 *buf, size_t len);
 typedef bool (*RzIOFdIsDbg)(RzIO *io, int fd);
 typedef const char *(*RzIOFdGetName)(RzIO *io, int fd);
 typedef RzList *(*RzIOFdGetMap)(RzIO *io, int fd);
@@ -321,21 +321,21 @@ RZ_API RzIODesc *rz_io_open_buffer(RzIO *io, RzBuffer *b, int flags, int mode);
 RZ_API bool rz_io_close(RzIO *io);
 RZ_API bool rz_io_reopen(RzIO *io, int fd, int flags, int mode);
 RZ_API int rz_io_close_all(RzIO *io);
-RZ_API int rz_io_pread_at(RzIO *io, ut64 paddr, ut8 *buf, int len);
-RZ_API int rz_io_pwrite_at(RzIO *io, ut64 paddr, const ut8 *buf, int len);
-RZ_API bool rz_io_vread_at_mapped(RzIO *io, ut64 vaddr, ut8 *buf, int len);
-RZ_API bool rz_io_read_at(RzIO *io, ut64 addr, ut8 *buf, int len);
-RZ_API bool rz_io_read_at_mapped(RzIO *io, ut64 addr, ut8 *buf, int len);
-RZ_API int rz_io_nread_at(RzIO *io, ut64 addr, ut8 *buf, int len);
-RZ_API bool rz_io_write_at(RzIO *io, ut64 addr, const ut8 *buf, int len);
-RZ_API bool rz_io_read(RzIO *io, ut8 *buf, int len);
-RZ_API bool rz_io_write(RzIO *io, const ut8 *buf, int len);
+RZ_API int rz_io_pread_at(RzIO *io, ut64 paddr, ut8 *buf, size_t len);
+RZ_API int rz_io_pwrite_at(RzIO *io, ut64 paddr, const ut8 *buf, size_t len);
+RZ_API bool rz_io_vread_at_mapped(RzIO *io, ut64 vaddr, ut8 *buf, size_t len);
+RZ_API bool rz_io_read_at(RzIO *io, ut64 addr, ut8 *buf, size_t len);
+RZ_API bool rz_io_read_at_mapped(RzIO *io, ut64 addr, ut8 *buf, size_t len);
+RZ_API int rz_io_nread_at(RzIO *io, ut64 addr, ut8 *buf, size_t len);
+RZ_API bool rz_io_write_at(RzIO *io, ut64 addr, const ut8 *buf, size_t len);
+RZ_API bool rz_io_read(RzIO *io, ut8 *buf, size_t len);
+RZ_API bool rz_io_write(RzIO *io, const ut8 *buf, size_t len);
 RZ_API ut64 rz_io_size(RzIO *io);
 RZ_API bool rz_io_is_listener(RzIO *io);
 RZ_API char *rz_io_system(RzIO *io, const char *cmd);
 RZ_API bool rz_io_resize(RzIO *io, ut64 newsize);
 RZ_API bool rz_io_extend_at(RzIO *io, ut64 addr, ut64 size);
-RZ_API bool rz_io_set_write_mask(RzIO *io, const ut8 *mask, int len);
+RZ_API bool rz_io_set_write_mask(RzIO *io, const ut8 *mask, size_t len);
 RZ_API void rz_io_bind(RzIO *io, RzIOBind *bnd);
 RZ_API bool rz_io_shift(RzIO *io, ut64 start, ut64 end, st64 move);
 RZ_API ut64 rz_io_seek(RzIO *io, ut64 offset, int whence);
@@ -346,10 +346,10 @@ RZ_API void rz_io_free(RzIO *io);
 RZ_API bool rz_io_plugin_init(RzIO *io);
 RZ_API bool rz_io_plugin_add(RzIO *io, RZ_NONNULL RZ_BORROW RzIOPlugin *plugin);
 RZ_API bool rz_io_plugin_del(RzIO *io, RZ_NONNULL RZ_BORROW RzIOPlugin *plugin);
-RZ_API int rz_io_plugin_read(RzIODesc *desc, ut8 *buf, int len);
-RZ_API int rz_io_plugin_write(RzIODesc *desc, const ut8 *buf, int len);
-RZ_API int rz_io_plugin_read_at(RzIODesc *desc, ut64 addr, ut8 *buf, int len);
-RZ_API int rz_io_plugin_write_at(RzIODesc *desc, ut64 addr, const ut8 *buf, int len);
+RZ_API int rz_io_plugin_read(RzIODesc *desc, ut8 *buf, size_t len);
+RZ_API int rz_io_plugin_write(RzIODesc *desc, const ut8 *buf, size_t len);
+RZ_API int rz_io_plugin_read_at(RzIODesc *desc, ut64 addr, ut8 *buf, size_t len);
+RZ_API int rz_io_plugin_write_at(RzIODesc *desc, ut64 addr, const ut8 *buf, size_t len);
 RZ_API RzIOPlugin *rz_io_plugin_resolve(RzIO *io, const char *filename, bool many);
 RZ_API RzIOPlugin *rz_io_plugin_get_default(RzIO *io, const char *filename, bool many);
 
@@ -358,8 +358,8 @@ RZ_API RzIODesc *rz_io_desc_new(RzIO *io, RzIOPlugin *plugin, const char *uri, i
 RZ_API RzIODesc *rz_io_desc_open(RzIO *io, const char *uri, int flags, int mode);
 RZ_API RzIODesc *rz_io_desc_open_plugin(RzIO *io, RzIOPlugin *plugin, const char *uri, int flags, int mode);
 RZ_API bool rz_io_desc_close(RzIODesc *desc);
-RZ_API int rz_io_desc_read(RzIODesc *desc, ut8 *buf, int count);
-RZ_API int rz_io_desc_write(RzIODesc *desc, const ut8 *buf, int count);
+RZ_API int rz_io_desc_read(RzIODesc *desc, ut8 *buf, size_t len);
+RZ_API int rz_io_desc_write(RzIODesc *desc, const ut8 *buf, size_t len);
 RZ_API void rz_io_desc_free(RzIODesc *desc);
 RZ_API bool rz_io_desc_add(RzIO *io, RzIODesc *desc);
 RZ_API bool rz_io_desc_del(RzIO *io, int fd);
@@ -375,8 +375,8 @@ RZ_API bool rz_io_desc_is_dbg(RzIODesc *desc);
 RZ_API int rz_io_desc_get_pid(RzIODesc *desc);
 RZ_API int rz_io_desc_get_tid(RzIODesc *desc);
 RZ_API bool rz_io_desc_get_base(RzIODesc *desc, ut64 *base);
-RZ_API int rz_io_desc_read_at(RzIODesc *desc, ut64 addr, ut8 *buf, int len);
-RZ_API int rz_io_desc_write_at(RzIODesc *desc, ut64 addr, const ut8 *buf, int len);
+RZ_API int rz_io_desc_read_at(RzIODesc *desc, ut64 addr, ut8 *buf, size_t len);
+RZ_API int rz_io_desc_write_at(RzIODesc *desc, ut64 addr, const ut8 *buf, size_t len);
 
 /* lifecycle */
 RZ_IPI bool rz_io_desc_init(RzIO *io);
@@ -389,13 +389,13 @@ RZ_API void rz_io_cache_commit(RzIO *io, ut64 from, ut64 to);
 RZ_API void rz_io_cache_init(RzIO *io);
 RZ_API void rz_io_cache_fini(RzIO *io);
 RZ_API void rz_io_cache_reset(RzIO *io, int set);
-RZ_API bool rz_io_cache_write(RzIO *io, ut64 addr, const ut8 *buf, int len);
-RZ_API bool rz_io_cache_read(RzIO *io, ut64 addr, ut8 *buf, int len);
+RZ_API bool rz_io_cache_write(RzIO *io, ut64 addr, const ut8 *buf, size_t len);
+RZ_API bool rz_io_cache_read(RzIO *io, ut64 addr, ut8 *buf, size_t len);
 
 /* io/p_cache.c */
 RZ_API bool rz_io_desc_cache_init(RzIODesc *desc);
-RZ_API int rz_io_desc_cache_write(RzIODesc *desc, ut64 paddr, const ut8 *buf, int len);
-RZ_API int rz_io_desc_cache_read(RzIODesc *desc, ut64 paddr, ut8 *buf, int len);
+RZ_API int rz_io_desc_cache_write(RzIODesc *desc, ut64 paddr, const ut8 *buf, size_t len);
+RZ_API int rz_io_desc_cache_read(RzIODesc *desc, ut64 paddr, ut8 *buf, size_t len);
 RZ_API bool rz_io_desc_cache_commit(RzIODesc *desc);
 RZ_API void rz_io_desc_cache_cleanup(RzIODesc *desc);
 RZ_API void rz_io_desc_cache_fini(RzIODesc *desc);
@@ -405,16 +405,16 @@ RZ_API RzList /*<RzIOCache *>*/ *rz_io_desc_cache_list(RzIODesc *desc);
 /* io/fd.c */
 RZ_API int rz_io_fd_open(RzIO *io, const char *uri, int flags, int mode);
 RZ_API bool rz_io_fd_close(RzIO *io, int fd);
-RZ_API int rz_io_fd_read(RzIO *io, int fd, ut8 *buf, int len);
-RZ_API int rz_io_fd_write(RzIO *io, int fd, const ut8 *buf, int len);
+RZ_API int rz_io_fd_read(RzIO *io, int fd, ut8 *buf, size_t len);
+RZ_API int rz_io_fd_write(RzIO *io, int fd, const ut8 *buf, size_t len);
 RZ_API ut64 rz_io_fd_seek(RzIO *io, int fd, ut64 addr, int whence);
 RZ_API ut64 rz_io_fd_size(RzIO *io, int fd);
 RZ_API ut8 *rz_io_fd_get_buf(RzIO *io, int fd, RZ_OUT RZ_NONNULL ut64 *size);
 RZ_API bool rz_io_fd_resize(RzIO *io, int fd, ut64 newsize);
 RZ_API bool rz_io_fd_is_blockdevice(RzIO *io, int fd);
 RZ_API bool rz_io_fd_is_chardevice(RzIO *io, int fd);
-RZ_API int rz_io_fd_read_at(RzIO *io, int fd, ut64 addr, ut8 *buf, int len);
-RZ_API int rz_io_fd_write_at(RzIO *io, int fd, ut64 addr, const ut8 *buf, int len);
+RZ_API int rz_io_fd_read_at(RzIO *io, int fd, ut64 addr, ut8 *buf, size_t len);
+RZ_API int rz_io_fd_write_at(RzIO *io, int fd, ut64 addr, const ut8 *buf, size_t len);
 RZ_API bool rz_io_fd_is_dbg(RzIO *io, int fd);
 RZ_API int rz_io_fd_get_pid(RzIO *io, int fd);
 RZ_API int rz_io_fd_get_tid(RzIO *io, int fd);
